# Copyright 2024 coScene
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
from sys import argv

from ruleengine.dsl.base_actions import noop
from .config_validator import validate_config

if __name__ == "__main__":
    config = json.loads(argv[1])
    result, _ = validate_config(config, noop)

    print(json.dumps(result))
    exit(0 if result["success"] else 1)
